searchData={"items":[{"type":"module","title":"GetHost","doc":"A cross-platform Elixir library for retrieving the fully qualified hostname of a system.\n\nThis module provides a unified interface for getting hostname information across different\noperating systems (macOS, Linux, and Windows). It handles platform-specific behavior and\nprovides consistent results regardless of the underlying operating system.","ref":"GetHost.html"},{"type":"module","title":"Platform-Specific Behavior - GetHost","doc":"The module handles hostname resolution differently based on the operating system:\n\n* On macOS: Returns the fully qualified domain name of the localhost\n* On Linux, Windows: Returns the IPv4 address or the expanded IPv6 address of the localhost","ref":"GetHost.html#module-platform-specific-behavior"},{"type":"module","title":"Examples - GetHost","doc":"> GetHost.name()\n    {:ok, \"example.com\"}  # On macOS\n    {:ok, \"192.168.1.1\"}  # On Linux/Windows","ref":"GetHost.html#module-examples"},{"type":"module","title":"Error Handling - GetHost","doc":"The module returns error tuples in case of failures:\n\n    > GetHost.name()\n    {:error, \"Not found \"hostname\"\"}  # When hostname command is not available\n    {:error, \"Fail to execute the \"hostname\" command.\"}  # When command execution fails","ref":"GetHost.html#module-error-handling"},{"type":"module","title":"Dependencies - GetHost","doc":"The module requires the following system commands to be available:\n* `hostname` - For getting the system hostname\n* `ping` - For resolving hostnames on Windows systems","ref":"GetHost.html#module-dependencies"},{"type":"function","title":"GetHost.name/0","doc":"Gets the fully qualified hostname of the system.\n\nThe function handles platform-specific behavior:\n* On macOS: Returns the fully qualified domain name of the localhost\n* On Linux and Windows: Returns the IPv4 address or the expanded IPv6 address of the localhost","ref":"GetHost.html#name/0"},{"type":"function","title":"Returns - GetHost.name/0","doc":"* `{:ok, hostname}` - Returns the fully qualified hostname as a string if successful\n  * `{:error, reason}` - Returns an error tuple with a `reason` if any step fails","ref":"GetHost.html#name/0-returns"},{"type":"module","title":"GetHost.Util","doc":"Utility functions for hostname and network operations.","ref":"GetHost.Util.html"},{"type":"function","title":"GetHost.Util.expand_ipv6/1","doc":"Expands an IPv6 address to its full form.\n\nThis function handles two types of IPv6 addresses:\n* Fully specified addresses (e.g., \"2001:db8:1:2:3:4:5:6\")\n* Compressed addresses with \"::\" (e.g., \"2001:db8::1\")\n\nThe function expands compressed addresses by:\n1. Splitting the address at \"::\"\n2. Calculating the number of missing segments\n3. Inserting \"0000\" for each missing segment\n4. Padding each segment to 4 characters with leading zeros","ref":"GetHost.Util.html#expand_ipv6/1"},{"type":"function","title":"Parameters - GetHost.Util.expand_ipv6/1","doc":"* `hostname` - The IPv6 address to expand","ref":"GetHost.Util.html#expand_ipv6/1-parameters"},{"type":"function","title":"Returns - GetHost.Util.expand_ipv6/1","doc":"* `binary()` - The expanded IPv6 address, or the original string if not an IPv6 address","ref":"GetHost.Util.html#expand_ipv6/1-returns"},{"type":"function","title":"Examples - GetHost.Util.expand_ipv6/1","doc":"iex> GetHost.Util.expand_ipv6(\"2001:db8::1\")\n    \"2001:0db8:0000:0000:0000:0000:0000:0001\"\n\n    iex> GetHost.Util.expand_ipv6(\"2001:db8:1:2:3:4:5:6\")\n    \"2001:0db8:0001:0002:0003:0004:0005:0006\"\n\n    iex> GetHost.Util.expand_ipv6(\"not-an-ipv6\")\n    \"not-an-ipv6\"","ref":"GetHost.Util.html#expand_ipv6/1-examples"},{"type":"function","title":"GetHost.Util.hostname_executable/0","doc":"Finds the path to the `hostname` executable in the system.","ref":"GetHost.Util.html#hostname_executable/0"},{"type":"function","title":"Returns - GetHost.Util.hostname_executable/0","doc":"* `{:ok, path}` - Returns the full `path` to the hostname executable if found\n  * `{:error, reason}` - Returns an error tuple with a `reason` if the executable is not found","ref":"GetHost.Util.html#hostname_executable/0-returns"},{"type":"function","title":"GetHost.Util.ping_executable/0","doc":"Finds the path to the `ping` executable in the system.","ref":"GetHost.Util.html#ping_executable/0"},{"type":"function","title":"Returns - GetHost.Util.ping_executable/0","doc":"* `{:ok, path}` - Returns the full `path` to the ping executable if found\n  * `{:error, reason}` - Returns an error tuple with a `reason` if the executable is not found","ref":"GetHost.Util.html#ping_executable/0-returns"},{"type":"function","title":"GetHost.Util.ping_raw_oneshot/1","doc":"Executes a single ping to the specified hostname without DNS resolution.\n\nThis function executes the `ping` command with different options based on the operating system:\n* On Unix-like systems (macOS, Linux): Uses `-n -c 1` options to prevent DNS resolution and send one packet\n* On Windows: Uses `/a /n 1` options for address resolution and a single ping","ref":"GetHost.Util.html#ping_raw_oneshot/1"},{"type":"function","title":"Parameters - GetHost.Util.ping_raw_oneshot/1","doc":"* `hostname` - The hostname or IP address to ping","ref":"GetHost.Util.html#ping_raw_oneshot/1-parameters"},{"type":"function","title":"Returns - GetHost.Util.ping_raw_oneshot/1","doc":"* `{:ok, result}` - Returns the ping command output as a string if successful\n  * `{:error, reason}` - Returns an error tuple with a `reason` if the command fails or executable is not found","ref":"GetHost.Util.html#ping_raw_oneshot/1-returns"},{"type":"function","title":"GetHost.Util.short_name/0","doc":"Gets the short hostname of the system using platform-specific options.\n\nThis function executes the `hostname` command with different options based on the operating system:\n* On macOS (Darwin): Uses `-f` option to get the fully qualified domain name\n* On Linux: Uses `-i` option to get the IP address\n* On Windows: Uses default `hostname` command without options","ref":"GetHost.Util.html#short_name/0"},{"type":"function","title":"Returns - GetHost.Util.short_name/0","doc":"* `{:ok, hostname}` - Returns the hostname as a string if successful\n  * `{:error, reason}` - Returns an error tuple with a `reason` if the command fails or executable is not found","ref":"GetHost.Util.html#short_name/0-returns"},{"type":"function","title":"GetHost.Util.to_fully_qualified_hostname/2","doc":"Converts a hostname to its fully qualified form based on the platform.\n\nThis function handles hostname resolution differently based on the operating system:\n* On Unix-like systems (macOS, Linux): Returns the hostname as is\n* On Windows: Uses `ping` command to resolve the hostname to its IP address","ref":"GetHost.Util.html#to_fully_qualified_hostname/2"},{"type":"function","title":"Parameters - GetHost.Util.to_fully_qualified_hostname/2","doc":"* `platform` - The platform tuple `{:unix, _}` or `{:win32, _}`\n  * `hostname` - The hostname to convert","ref":"GetHost.Util.html#to_fully_qualified_hostname/2-parameters"},{"type":"function","title":"Returns - GetHost.Util.to_fully_qualified_hostname/2","doc":"* `{:ok, ip}` - Returns the IP address as a string if successful\n  * `{:error, reason}` - Returns an error tuple with a `reason` if the resolution fails","ref":"GetHost.Util.html#to_fully_qualified_hostname/2-returns"},{"type":"extras","title":"GetHost","doc":"# GetHost\n\nA cross-platform Elixir library for retrieving the fully qualified hostname of a system. This library provides a unified interface for getting hostname information across different operating systems (macOS, Linux, and Windows).","ref":"readme.html"},{"type":"extras","title":"Features - GetHost","doc":"- Platform-specific hostname resolution\n- IPv6 address expansion support\n- Cross-platform compatibility (macOS, Linux, Windows)\n- Simple and consistent API","ref":"readme.html#features"},{"type":"extras","title":"Usage - GetHost","doc":"```elixir\n# Get the fully qualified hostname\n{:ok, hostname} = GetHost.name()\n```\n\nThe library handles platform-specific behavior:\n- On macOS: Returns the fully qualified domain name of the localhost\n- On Linux and Windows: Returns the IPv4 address or the expanded IPv6 address of the localhost","ref":"readme.html#usage"},{"type":"extras","title":"Installation - GetHost","doc":"The package can be installed by adding `get_host` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:get_host, \"~> 1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Tested Platforms - GetHost","doc":"* Ubuntu 22.04 / Elixir 1.18 / OTP 27\n* Ubuntu 22.04 / Elixir 1.17 / OTP 27\n* Ubuntu 22.04 / Elixir 1.16 / OTP 26\n* Ubuntu 22.04 / Elixir 1.15 / OTP 25\n* Windows 2022 / Elixir 1.18 / OTP 27\n* Windows 2019 / Elixir 1.18 / OTP 27","ref":"readme.html#tested-platforms"},{"type":"extras","title":"License - GetHost","doc":"Copyright (c) 2025 University of Kitakyushu\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#license"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}